/**
 * The MIT License (MIT)
 *
 * Copyright (C) 2013 Jaroslav Tulach <jaroslav.tulach@apidesign.org>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.apidesign.html.demo.chess;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Properties;
import net.java.html.json.ComputedProperty;
import net.java.html.json.Model;
import net.java.html.json.ModelOperation;
import net.java.html.json.Property;

/**
 *
 * @author Jaroslav Tulach <jtulach@netbeans.org>
 */
@Model(className = "Settings", properties = {
    @Property(name = "username", type = String.class),
    @Property(name = "password", type = String.class),
    @Property(name = "url", type = String.class),
})
class SettingsModel {
    private static final String SETTINGS = ".j1chess/html.properties";
    private static final String DEFAULT_URL = "ws://localhost:8080/chess/chessserver";
    
    @ComputedProperty static boolean validCredentials(String username, String password) {
        return username != null && password != null && !username.isEmpty() && !password.isEmpty();
    }
    
    @ModelOperation static void read(Settings s) {
        File prefs = new File(System.getProperty("user.home"), SETTINGS);
        try (FileInputStream is = new FileInputStream(prefs)) {
            Properties p = new Properties();
            p.load(is);
            
            s.setUsername(p.getProperty("username", ""));
            s.setPassword(p.getProperty("password", ""));
            s.setUrl(p.getProperty("url", DEFAULT_URL));
        } catch (Throwable ex) {
            s.setUsername("");
            s.setPassword("");
            s.setUrl(DEFAULT_URL);
        }
    }
    
    @ModelOperation static void write(Settings s, UI ui) {
        File prefs = new File(System.getProperty("user.home"), SETTINGS);
        prefs.getParentFile().mkdirs();
        try (FileOutputStream os = new FileOutputStream(prefs)) {
            Properties p = new Properties();
            p.setProperty("username", s.getUsername());
            p.setProperty("password", s.getPassword());
            p.setProperty("url", s.getUrl());
            p.store(os, "Java One Chess Preferences for HTML/Java Client");
        } catch (Throwable ex) {
            ui.setStatus("Cannot save preferences: " + ex.getMessage());
        }
    }
}
